@@ -10,6 +10,7 @@
 #include "PROPOSAL/crosssection/Factories/MupairProductionFactory.h"
 #include "PROPOSAL/crosssection/Factories/PhotoPairProductionFactory.h"
 #include "PROPOSAL/crosssection/Factories/PhotonuclearFactory.h"
+#include "PROPOSAL/crosssection/Factories/PhotoproductionFactory.h"
 #include "PROPOSAL/crosssection/Factories/WeakInteractionFactory.h"
 #include "PROPOSAL/crosssection/ParticleDefaultCrossSectionList.h"
 #include "PROPOSAL/density_distr/density_distr.h"
@@ -91,8 +92,9 @@ Secondaries Propagator::Propagate(const ParticleState& initial_particle,
         case ReachedInteraction:
             switch (next_interaction_type) {
             case Stochastic: {
-                auto type = DoStochasticInteraction(state, utility, rnd);
-                track.push_back(state, type);
+                auto loss = DoStochasticInteraction(state, utility, rnd);
+                if (loss.type != InteractionType::Undefined)
+                    track.push_back(state, loss.type, loss.comp_hash);
                 if (state.energy <= InteractionEnergy[MinimalE])
                     continue_propagation = false;
                 break;
@@ -125,7 +127,7 @@ Secondaries Propagator::Propagate(const ParticleState& initial_particle,
     return track;
 }
 
-InteractionType Propagator::DoStochasticInteraction(ParticleState& p_cond,
+Interaction::Loss Propagator::DoStochasticInteraction(ParticleState& p_cond,
     PropagationUtility& utility, std::function<double()> rnd)
 {
     auto loss = utility.EnergyStochasticloss(p_cond.energy, rnd());
@@ -134,7 +136,7 @@ InteractionType Propagator::DoStochasticInteraction(ParticleState& p_cond,
         p_cond.energy * (1. - loss.v_loss), p_cond.direction, rnd);
     p_cond.energy = p_cond.energy * (1. - loss.v_loss);
 
-    return loss.type;
+    return loss;
 }
 
 int Propagator::AdvanceParticle(ParticleState& state, double E_f,
@@ -181,11 +183,18 @@ int Propagator::AdvanceParticle(ParticleState& state, double E_f,
 
     if (advancement_type != ReachedInteraction) {
         double control_distance;
+        double energy_next_interaction = E_f;
         do {
             advance_distance = AdvanceDistance[advancement_type];
-            advance_grammage = density->Calculate(
-                state.position, state.direction, advance_distance);
-            E_f = utility.EnergyDistance(state.energy, advance_grammage);
+            if (advancement_type == ReachedInteraction) {
+                // avoid recalculation if we go back to this case
+                advance_grammage = grammage_next_interaction;
+                E_f = energy_next_interaction;
+            } else {
+                advance_grammage = density->Calculate(
+                        state.position, state.direction, advance_distance);
+                E_f = utility.EnergyDistance(state.energy, advance_grammage);
+            }
 
             std::tie(mean_direction, new_direction) = utility.DirectionsScatter(
                 advance_grammage, state.energy, E_f, state.direction, rnd);
@@ -282,6 +291,11 @@ Sector Propagator::GetCurrentSector(
 
 nlohmann::json Propagator::ParseConfig(const string& config_file)
 {
+    std::ifstream f(config_file.c_str());
+    if (!f.good()) {
+        throw std::invalid_argument("No configuration file found under "
+                                    "path "+ config_file);
+    }
     nlohmann::json json_config;
     try {
         if (config_file== "")
@@ -417,6 +431,9 @@ Propagator::CreateCrossSectionList(const ParticleDef& p_def,
                 p_def, medium, cuts, interpolate, config["photo"]));
         }
     }
+    if (config.contains("photoproduction"))
+        cross.emplace_back(make_photoproduction(
+                p_def, medium, config["photoproduction"]));
     if (config.contains("photopair"))
         cross.emplace_back(make_photopairproduction(
             p_def, medium, interpolate, config["photopair"]));
