@@ -27,21 +27,26 @@ void Secondaries::reserve(size_t number_secondaries)
 {
     track_.reserve(number_secondaries);
     types_.reserve(number_secondaries);
+    target_hashes_.reserve(number_secondaries);
 }
 
-void Secondaries::push_back(const ParticleState& point, const InteractionType& type)
+void Secondaries::push_back(const ParticleState& point,
+                            const InteractionType& type, const size_t& target_hash)
 {
     track_.push_back(point);
     types_.push_back(type);
+    target_hashes_.push_back(target_hash);
 }
 
 void Secondaries::emplace_back(const ParticleType& particle_type, const Vector3D& position,
     const Vector3D& direction, const double& energy, const double& time,
-    const double& distance, const InteractionType& interaction_type)
+    const double& distance, const InteractionType& interaction_type,
+    const size_t& target_hash)
 {
     track_.emplace_back(particle_type, position, direction, energy, time,
                         distance);
     types_.emplace_back(interaction_type);
+    target_hashes_.push_back(target_hash);
 }
 
 std::vector<ParticleState> Secondaries::GetDecayProducts() const
@@ -243,6 +248,29 @@ std::shared_ptr<ParticleState> Secondaries::GetClosestApproachPoint(const Geomet
     return std::make_unique<ParticleState>(track_.back());
 }
 
+bool Secondaries::HitGeometry(const Geometry& geometry) const {
+    for (unsigned int i = 0; i < track_.size() - 1; i++) {
+        auto pos_a = track_.at(i).position;
+        auto dir_a = track_.at(i).direction;
+        auto pos_b = track_.at(i + 1).position;
+        auto dir_b = track_.at(i + 1).direction;
+
+        // check if first track point lies inside geometry
+        if (geometry.IsInside(pos_a, dir_a))
+            return true;
+
+        // check if geometry lies between two track points
+        if (geometry.IsInfront(pos_a, dir_a) && geometry.IsBehind(pos_b, dir_b))
+            return true;
+    }
+
+    // check if last track point is in geometry
+    if (geometry.IsInside(track_.back().position, track_.back().direction))
+        return true;
+
+    return false;
+}
+
 ParticleState Secondaries::RePropagateEnergy(const ParticleState& init,
                                              double energy_lost,
                                              double max_distance) const
@@ -332,7 +360,7 @@ std::vector<StochasticLoss> Secondaries::GetStochasticLosses() const
                                 track_[i-1].energy - track_[i].energy,
                                 track_[i].position, track_[i].direction,
                                 track_[i].time, track_[i].propagated_distance,
-                                track_[i-1].energy);
+                                track_[i-1].energy, target_hashes_[i]);
         }
     }
     return losses;
@@ -352,7 +380,7 @@ std::vector<StochasticLoss> Secondaries::GetStochasticLosses(const Geometry& geo
                                     track_[i-1].energy - track_[i].energy,
                                     track_[i].position, track_[i].direction,
                                     track_[i].time, track_[i].propagated_distance,
-                                    track_[i-1].energy);
+                                    track_[i-1].energy, target_hashes_[i]);
             }
         }
     }
@@ -371,7 +399,7 @@ std::vector<StochasticLoss> Secondaries::GetStochasticLosses(const InteractionTy
                                 track_[i-1].energy - track_[i].energy,
                                 track_[i].position, track_[i].direction,
                                 track_[i].time, track_[i].propagated_distance,
-                                track_[i-1].energy);
+                                track_[i-1].energy, target_hashes_[i]);
         }
     }
     return losses;
@@ -398,8 +426,8 @@ std::vector<ContinuousLoss> Secondaries::GetContinuousLosses() const
     for (unsigned int i=1; i<track_.size(); i++) {
         if (types_[i] == InteractionType::ContinuousEnergyLoss) {
             losses.emplace_back( track_[i-1].energy - track_[i].energy,
-                                 track_[i-1].energy, track_[i-1].position,
-                                 (track_[i].position - track_[i-1].position).magnitude(),
+                                 track_[i-1].energy,
+                                 track_[i-1].position, track_[i].position,
                                  track_[i-1].direction, track_[i].direction,
                                  track_[i-1].time, track_[i].time);
         }
@@ -419,8 +447,8 @@ std::vector<ContinuousLoss> Secondaries::GetContinuousLosses(const Geometry& geo
             if (types_[i] == InteractionType::ContinuousEnergyLoss) {
                 losses.emplace_back(
                         track_[i-1].energy - track_[i].energy,
-                        track_[i-1].energy, track_[i-1].position,
-                        (track_[i].position - track_[i-1].position).magnitude(),
+                        track_[i-1].energy,
+                        track_[i-1].position, track_[i].position,
                         track_[i-1].direction, track_[i].direction,
                         track_[i-1].time, track_[i].time);
             }
