@@ -2,6 +2,7 @@
 
 #include "PROPOSAL/particle/Particle.h"
 #include "PROPOSAL/particle/ParticleDef.h"
+#include "PROPOSAL/medium/Components.h"
 #include "PROPOSAL/Secondaries.h"
 #include "PROPOSAL/geometry/Geometry.h"
 #include "pyPROPOSAL/pyBindings.h"
@@ -16,6 +17,11 @@ using namespace PROPOSAL;
 void init_particle(py::module& m) {
     py::module m_sub = m.def_submodule("particle");
 
+    m_sub.def("get_ParticleDef_for_type", &ParticleDef::GetParticleDefForType,
+              py::arg("particle_type"), R"pbdoc(
+                Get ParticleDef for given particle_type
+    )pbdoc");
+
     m_sub.doc() = R"pbdoc(
         For each propagation a defined particle is needed.
         You have the possibility to define one by your own or select one of
@@ -265,20 +271,24 @@ void init_particle(py::module& m) {
             .def_readwrite("parent_particle_energy", &Loss::parent_particle_energy, R"pbdoc(Particle energy in MeV at the time of the stochastic loss or at the beginning of the continuous loss.)pbdoc");
 
     py::class_<StochasticLoss, Loss, std::shared_ptr<StochasticLoss>>(m_sub, "StochasticLoss")
-            .def(py::init<const int&, const double&, const Vector3D&, const Vector3D&, const double&, const double&, const double &>(),
+            .def(py::init<const int&, const double&, const Vector3D&, const Vector3D&, const double&, const double&, const double &, const size_t&>(),
                  py::arg("type"), py::arg("loss_energy"), py::arg("position"),
                  py::arg("direction"), py::arg("time"),
                  py::arg("propagated_distance"),
-                 py::arg("parent_particle_energy"))
+                 py::arg("parent_particle_energy"),
+                 py::arg("target_hash") = 0)
             .def_readwrite("position", &StochasticLoss::position, R"pbdoc(Position of stochastic interaction.)pbdoc")
             .def_readwrite("direction", &StochasticLoss::direction, R"pbdoc(Direction of stochastic loss.)pbdoc")
             .def_readwrite("time", &StochasticLoss::time, R"pbdoc(Time when stochastic loss occured.)pbdoc")
+            .def_readwrite("target_hash", &StochasticLoss::target_hash, R"pbdoc(Hash of target with which the stochastic interaction happened. Can be the hash of a Component or the hash of a Medium`.)pbdoc")
             .def_readwrite("propagated_distance", &StochasticLoss::propagated_distance, R"pbdoc(Distance (in cm) the parent particle has propagated when the stochastic loss occured.)pbdoc");
 
     py::class_<ContinuousLoss, Loss, std::shared_ptr<ContinuousLoss>>(m_sub, "ContinuousLoss")
-            .def(py::init<const double&, const double&, const Vector3D&, const double&, const Vector3D&, const Vector3D&, const double&, const double&>())
-            .def_readwrite("length", &ContinuousLoss::length, R"pbdoc(Length of continuous loss in cm.)pbdoc")
+            .def(py::init<const double&, const double&, const Vector3D&, const Vector3D&, const Vector3D&, const Vector3D&, const double&, const double&>(),
+                 py::arg("energy"), py::arg("parent_particle_energy"), py::arg("start_position"), py::arg("end_position"),
+                 py::arg("direction_initial"), py::arg("direction_final"), py::arg("time_initial"), py::arg("time_final"))
             .def_readwrite("start_position", &ContinuousLoss::start_position, R"pbdoc(Position where the continuous energy loss started.)pbdoc")
+            .def_readwrite("end_position", &ContinuousLoss::end_position, R"pbdoc(Position where the continuous energy loss ended.)pbdoc")
             .def_readwrite("direction_initial", &ContinuousLoss::direction_initial, R"pbdoc(Direction of the particle at the beginning of the continuous energy loss.)pbdoc")
             .def_readwrite("direction_final", &ContinuousLoss::direction_final, R"pbdoc(Direction of the particle at the end of the continuous energy loss.)pbdoc")
             .def_readwrite("time_initial", &ContinuousLoss::time_initial, R"pbdoc(Time when the continuous energy loss started.)pbdoc")
@@ -289,6 +299,7 @@ void init_particle(py::module& m) {
             .def("entry_point", &Secondaries::GetEntryPoint)
             .def("exit_point", &Secondaries::GetExitPoint)
             .def("closest_approach_point", &Secondaries::GetClosestApproachPoint)
+            .def("hit_geometry", &Secondaries::HitGeometry)
             .def("track", overload_cast_<>()(&Secondaries::GetTrack, py::const_))
             .def("track", overload_cast_<const Geometry&>()(&Secondaries::GetTrack, py::const_))
             .def("get_state_for_energy", &Secondaries::GetStateForEnergy)
@@ -300,6 +311,7 @@ void init_particle(py::module& m) {
             .def("track_propagated_distances", &Secondaries::GetTrackPropagatedDistances)
             .def("track_types", &Secondaries::GetTrackTypes)
             .def("track_length", &Secondaries::GetTrackLength)
+            .def("target_hashes", &Secondaries::GetTargetHashes)
             .def("stochastic_losses", overload_cast_<>()(&Secondaries::GetStochasticLosses, py::const_))
             .def("stochastic_losses", overload_cast_<const Geometry&>()(&Secondaries::GetStochasticLosses, py::const_))
             .def("stochastic_losses", overload_cast_<const InteractionType&>()(&Secondaries::GetStochasticLosses, py::const_))
@@ -310,18 +322,19 @@ void init_particle(py::module& m) {
 
     py::enum_<InteractionType>(m_sub, "Interaction_Type")
         .value("particle", InteractionType::Particle)
-        .value("brems",InteractionType::Brems)
-        .value("ioniz",InteractionType::Ioniz)
-        .value("epair",InteractionType::Epair)
-        .value("photonuclear",InteractionType::Photonuclear)
-        .value("mupair",InteractionType::MuPair)
-        .value("hadrons",InteractionType::Hadrons)
-        .value("continuousenergyloss",InteractionType::ContinuousEnergyLoss)
-        .value("weakint",InteractionType::WeakInt)
-        .value("compton",InteractionType::Compton)
-        .value("decay",InteractionType::Decay)
-        .value("annihilation",InteractionType::Annihilation)
-        .value("photopair",InteractionType::Photopair);
+        .value("brems", InteractionType::Brems)
+        .value("ioniz", InteractionType::Ioniz)
+        .value("epair", InteractionType::Epair)
+        .value("photonuclear", InteractionType::Photonuclear)
+        .value("mupair", InteractionType::MuPair)
+        .value("hadrons", InteractionType::Hadrons)
+        .value("continuousenergyloss", InteractionType::ContinuousEnergyLoss)
+        .value("weakint", InteractionType::WeakInt)
+        .value("compton", InteractionType::Compton)
+        .value("decay", InteractionType::Decay)
+        .value("annihilation", InteractionType::Annihilation)
+        .value("photopair", InteractionType::Photopair)
+        .value("photoproduction", InteractionType::Photoproduction);
 
    py::enum_<ParticleType>(m_sub, "Particle_Type")
         .value("None", ParticleType::None)
